==> regressionmadesimple-1.0.3-py3-none-any.whl: regressionmadesimple/regressionmadesimple.py <==
import sklearn.model_selection as ms # Avoid naming comflicts with the train_test_split
from sklearn.linear_model import LinearRegression
from sklearn.metrics import mean_squared_error
import pandas as pd
import numpy as np
# import plotly.express as px
import plotly.graph_objects as go
# import matplotlib.pyplot as plt
# import seaborn as sns
# Add more if needed

class preworks:
    @staticmethod
    def readcsv(path):
        df = pd.read_csv(path)
        return df

    @staticmethod
    def _create_random_dataset(nrows:int, ncols:int, randrange:tuple, colnames:list):
        df = pd.DataFrame(np.random.randint(randrange[0], randrange[1], size=(nrows, ncols)), columns=colnames)
        return df
    
    @staticmethod
    def crd(**kwargs):
        return preworks._create_random_dataset(**kwargs)

class Linear:
    def __init__(self, dataset: pd.Series|pd.DataFrame, colX:str, colY:str, testsize=0.15, randomstate:int=1, train_test_split:bool=True):
        self.dataset = dataset
        self.colX = colX
        self.colY = colY
        self.testsize = testsize
        self.randomstate = randomstate
        self.X = dataset[colX]
        self.y = dataset[colY]
        if train_test_split:
            self.X_train, self.X_test, self.y_train, self.y_test = ms.train_test_split(self.X, self.y, test_size=self.testsize, random_state=self.randomstate)
            self.model = LinearRegression()
            self.model.fit(self.X_train, self.y_train)
            self.y_pred_tts = self.model.predict(self.X_test)
            self.mse_tts = mean_squared_error(self.y_test, self.y_pred_tts)
        else:
            self.model = LinearRegression()
            self.model.fit(self.X, self.y)

    def plot(self):
        """
        Note that this only returns the plotly figure. Please use fig.show() yourself.
        This only works if you have the `train_test_split` parameter set to True (default) in the constructor.
        """
        if not hasattr(self, 'y_pred_tts'):
            raise Exception('Please set the `train_test_split` parameter to True in the constructor to use this function.')
        fig = go.Figure()
        fig.add_trace(go.Scatter(x=self.X_test, y=self.y_test, mode='markers', name='Test Data'))
        fig.add_trace(go.Scatter(x=self.X_test, y=self.y_pred_tts, mode='lines', name='Prediction'))
        return fig
    
    def predict(self, X_new: np.array|pd.DataFrame):
        return self.model.predict(X_new)
    
    def plotpredict(self, X_new: np.array|pd.DataFrame, y_new: np.array|pd.DataFrame):
        """
        Note that this only returns the plotly figure. Please use fig.show() yourself.
        """
        fig = go.Figure()
        fig.add_trace(go.Scatter(x=X_new, y=y_new, mode='markers', name='New Data'))
        fig.add_trace(go.Scatter(x=X_new, y=self.predict(X_new), mode='lines', name='Prediction'))
        return fig

==> regressionmadesimple-1.0.6-py3-none-any.whl: regressionmadesimple/regressionmadesimple.py <==
import sklearn.model_selection as ms # Avoid naming comflicts with the train_test_split
from sklearn.linear_model import LinearRegression
from sklearn.metrics import mean_squared_error
import pandas as pd
import numpy as np
# import plotly.express as px
import plotly.graph_objects as go
# import matplotlib.pyplot as plt
# import seaborn as sns
# Add more if needed

class preworks:
    @staticmethod
    def readcsv(path):
        df = pd.read_csv(path)
        return df

    @staticmethod
    def _create_random_dataset(nrows:int, ncols:int, randrange:tuple, colnames:list):
        df = pd.DataFrame(np.random.randint(randrange[0], randrange[1], size=(nrows, ncols)), columns=colnames)
        return df
    
    @staticmethod
    def crd(**kwargs):
        return preworks._create_random_dataset(**kwargs)

class Linear:
    def __init__(self, dataset: pd.Series|pd.DataFrame, colX:str, colY:str, testsize=0.15, randomstate:int=1, train_test_split:bool=True):
        self.dataset = dataset
        self.colX = colX
        self.colY = colY
        self.testsize = testsize
        self.randomstate = randomstate
        self.X = dataset[colX]
        self.y = dataset[colY]
        if train_test_split:
            self.X_train, self.X_test, self.y_train, self.y_test = ms.train_test_split(self.X, self.y, test_size=self.testsize, random_state=self.randomstate)
            self.model = LinearRegression()
            self.model.fit(self.X_train, self.y_train)
            self.y_pred_tts = self.model.predict(self.X_test)
            self.mse_tts = mean_squared_error(self.y_test, self.y_pred_tts)
        else:
            self.model = LinearRegression()
            self.model.fit(self.X, self.y)

    def plot(self):
        """
        Note that this only returns the plotly figure. Please use fig.show() yourself.
        This only works if you have the `train_test_split` parameter set to True (default) in the constructor.
        """
        if not hasattr(self, 'y_pred_tts'):
            raise Exception('Please set the `train_test_split` parameter to True in the constructor to use this function.')
        fig = go.Figure()
        fig.add_trace(go.Scatter(x=self.X_test, y=self.y_test, mode='markers', name='Test Data'))
        fig.add_trace(go.Scatter(x=self.X_test, y=self.y_pred_tts, mode='lines', name='Prediction'))
        return fig
    
    def predict(self, X_new: np.ndarray|pd.DataFrame):
        return self.model.predict(X_new)
    
    def plotpredict(self, X_new: np.ndarray|pd.DataFrame, y_new: np.array|pd.DataFrame):
        """
        Note that this only returns the plotly figure. Please use fig.show() yourself.
        """
        fig = go.Figure()
        fig.add_trace(go.Scatter(x=X_new, y=y_new, mode='markers', name='New Data'))
        fig.add_trace(go.Scatter(x=X_new, y=self.predict(X_new), mode='lines', name='Prediction'))
        return fig
